@@ -89,7 +89,7 @@ def configure(name, default_version=None, default_service_type=None,
         variable is not specified, validation will assume that your client
         doesn't allow to specify service type.
     :param supported_versions: List of supported versions(If this variable is
-        not specified, `OSClients.validate_version` method will raise an
+        not specified, `OSClient.validate_version` method will raise an
         exception that client doesn't support setting any versions. If this
         logic is wrong for your client, you should override `validate_version`
         in client object)
@@ -550,24 +550,6 @@ class Manila(OSClient):
         return manila_client
 
 
-@configure("ceilometer", default_version="2", default_service_type="metering",
-           supported_versions=["1", "2"])
-class Ceilometer(OSClient):
-    """Wrapper for CeilometerClient which returns authenticated native client.
-
-    """
-
-    def create_client(self, version=None, service_type=None):
-        """Return ceilometer client."""
-        from ceilometerclient import client as ceilometer
-
-        client = ceilometer.get_client(
-            self.choose_version(version),
-            session=self.keystone.get_session()[0],
-            endpoint_override=self._get_endpoint(service_type))
-        return client
-
-
 @configure("gnocchi", default_service_type="metric", default_version="1",
            supported_versions=["1"])
 class Gnocchi(OSClient):
@@ -678,7 +660,7 @@ class Murano(OSClient):
 
 
 @configure("designate", default_version="2", default_service_type="dns",
-           supported_versions=["1", "2"])
+           supported_versions=["2"])
 class Designate(OSClient):
     """Wrapper for DesignateClient which returns authenticated native client.
 
@@ -694,11 +676,8 @@ class Designate(OSClient):
         api_url += "/v%s" % version
 
         session = self.keystone.get_session()[0]
-        if version == "2":
-            return client.Client(version, session=session,
-                                 endpoint_override=api_url)
         return client.Client(version, session=session,
-                             endpoint=api_url)
+                             endpoint_override=api_url)
 
 
 @configure("trove", default_version="1.0", supported_versions=["1.0"],
