@@ -20,7 +20,6 @@ from rally.task import types
 from rally.task import validation
 
 from rally_openstack.common import consts
-from rally_openstack.common.wrappers import network as network_wrapper
 from rally_openstack.task import scenario
 from rally_openstack.task.scenarios.cinder import utils as cinder_utils
 from rally_openstack.task.scenarios.neutron import utils as neutron_utils
@@ -37,7 +36,7 @@ LOG = logging.getLogger(__name__)
                flavor={"type": "nova_flavor"})
 @validation.add("image_valid_on_flavor", flavor_param="flavor",
                 image_param="image")
-@validation.add("required_services", services=(consts.Service.NOVA))
+@validation.add("required_services", services=[consts.Service.NOVA])
 @validation.add("required_platform", platform="openstack", users=True)
 @scenario.configure(context={"cleanup@openstack": ["nova"]},
                     name="NovaServers.boot_and_list_server",
@@ -902,33 +901,47 @@ class BootAndRebuildServer(utils.NovaScenario):
         self._delete_server(server)
 
 
+@logging.log_deprecated_args(
+    "Use 'floating_network' for additional instance parameters.",
+    "2.1.0", ["create_floating_ip_args"], once=True)
 @types.convert(image={"type": "glance_image"},
                flavor={"type": "nova_flavor"})
 @validation.add("image_valid_on_flavor", flavor_param="flavor",
                 image_param="image")
 @validation.add("required_services", services=[consts.Service.NOVA])
 @validation.add("required_platform", platform="openstack", users=True)
-@validation.add("required_contexts", contexts=("network"))
+@validation.add("required_contexts", contexts=["network"])
 @scenario.configure(
     context={"cleanup@openstack": ["nova", "neutron.floatingip"]},
     name="NovaServers.boot_and_associate_floating_ip",
     platform="openstack")
 class BootAndAssociateFloatingIp(utils.NovaScenario):
 
-    def run(self, image, flavor, create_floating_ip_args=None, **kwargs):
+    def run(self, image, flavor, floating_network=None,
+            create_floating_ip_args=None, **kwargs):
         """Boot a server and associate a floating IP to it.
 
         :param image: image to be used to boot an instance
         :param flavor: flavor to be used to boot an instance
-        :param create_floating_ip_args: Optional additional arguments for
-                                        floating ip creation
+        :param floating_network: external network associated with floating IP.
+        :param create_floating_ip_args: Optional additional dict for specifying
+            external network associated with floating IP ('ext_network' key).
         :param kwargs: Optional additional arguments for server creation
         """
-        create_floating_ip_args = create_floating_ip_args or {}
+        if floating_network is None and create_floating_ip_args:
+            if "ext_network" in create_floating_ip_args:
+                # the old way (network wrapper)
+                floating_network = create_floating_ip_args["ext_network"]
+            elif "floating_network" in create_floating_ip_args:
+                # the semi-old way - the time when network wrapper was replaced
+                #   by network service, but this compatibility layer was not
+                #   provided
+                floating_network = create_floating_ip_args["floating_network"]
         server = self._boot_server(image, flavor, **kwargs)
-        address = network_wrapper.wrap(self.clients, self).create_floating_ip(
-            tenant_id=server.tenant_id, **create_floating_ip_args)
-        self._associate_floating_ip(server, address["ip"])
+        floatingip = self.neutron.create_floatingip(
+            floating_network=floating_network
+        )
+        self._associate_floating_ip(server, floatingip)
 
 
 @types.convert(image={"type": "glance_image"},
@@ -1085,20 +1098,24 @@ class BootServerFromVolumeSnapshot(utils.NovaScenario,
                           **kwargs)
 
 
+@logging.log_deprecated_args(
+    "Use 'floating_network' for additional instance parameters.",
+    "2.1.0", ["create_floating_ip_args"], once=True)
 @types.convert(image={"type": "glance_image"},
                flavor={"type": "nova_flavor"})
 @validation.add("image_valid_on_flavor", flavor_param="flavor",
                 image_param="image")
 @validation.add("required_services", services=[consts.Service.NOVA])
 @validation.add("required_platform", platform="openstack", users=True)
-@validation.add("required_contexts", contexts=("network"))
+@validation.add("required_contexts", contexts=["network"])
 @scenario.configure(
     context={"cleanup@openstack": ["nova", "neutron.floatingip"]},
     name="NovaServers.boot_server_associate_and_dissociate_floating_ip",
     platform="openstack")
 class BootServerAssociateAndDissociateFloatingIP(utils.NovaScenario):
 
-    def run(self, image, flavor, create_floating_ip_args=None, **kwargs):
+    def run(self, image, flavor, floating_network=None,
+            create_floating_ip_args=None, **kwargs):
         """Boot a server associate and dissociate a floating IP from it.
 
         The scenario first boot a server and create a floating IP. then
@@ -1107,17 +1124,26 @@ class BootServerAssociateAndDissociateFloatingIP(utils.NovaScenario):
 
         :param image: image to be used to boot an instance
         :param flavor: flavor to be used to boot an instance
-        :param create_floating_ip_args: Optional additional arguments for
-                                        floating ip creation
+        :param floating_network: external network associated with floating IP.
+        :param create_floating_ip_args: Optional additional dict for specifying
+            external network associated with floating IP ('ext_network' key).
         :param kwargs: Optional additional arguments for server creation
         """
-
-        create_floating_ip_args = create_floating_ip_args or {}
+        if floating_network is None and create_floating_ip_args:
+            if "ext_network" in create_floating_ip_args:
+                # the old way (network wrapper)
+                floating_network = create_floating_ip_args["ext_network"]
+            elif "floating_network" in create_floating_ip_args:
+                # the semi-old way - the time when network wrapper was replaced
+                #   by network service, but this compatibility layer was not
+                #   provided
+                floating_network = create_floating_ip_args["floating_network"]
         server = self._boot_server(image, flavor, **kwargs)
-        address = network_wrapper.wrap(self.clients, self).create_floating_ip(
-            tenant_id=server.tenant_id, **create_floating_ip_args)
-        self._associate_floating_ip(server, address["ip"])
-        self._dissociate_floating_ip(server, address["ip"])
+        floatingip = self.neutron.create_floatingip(
+            floating_network=floating_network
+        )
+        self._associate_floating_ip(server, floatingip)
+        self._dissociate_floating_ip(server, floatingip)
 
 
 @types.convert(image={"type": "glance_image"},
@@ -1126,7 +1152,7 @@ class BootServerAssociateAndDissociateFloatingIP(utils.NovaScenario):
                 image_param="image")
 @validation.add("required_services", services=[consts.Service.NOVA])
 @validation.add("required_platform", platform="openstack", users=True)
-@validation.add("required_contexts", contexts=("network"))
+@validation.add("required_contexts", contexts=["network"])
 @scenario.configure(context={"cleanup@openstack": ["nova"]},
                     name="NovaServers.boot_server_and_list_interfaces",
                     platform="openstack")
