@@ -919,9 +919,15 @@ class NovaServersTestCase(test.ScenarioTestCase):
         scenario._get_console_url_server.assert_called_once_with(
             server, "novnc")
 
-    @mock.patch(NOVA_SERVERS_MODULE + ".network_wrapper.wrap")
-    def test_boot_and_associate_floating_ip(self, mock_wrap):
-        scenario = servers.BootAndAssociateFloatingIp(self.context)
+    def test_boot_and_associate_floating_ip(self):
+        clients = mock.MagicMock(credential=mock.MagicMock(api_info={}))
+        neutronclient = clients.neutron.return_value
+        floatingip = "floatingip"
+        neutronclient.create_floatingip.return_value = {
+            "floatingip": floatingip}
+
+        scenario = servers.BootAndAssociateFloatingIp(self.context,
+                                                      clients=clients)
         server = mock.Mock()
         scenario._boot_server = mock.Mock(return_value=server)
         scenario._associate_floating_ip = mock.Mock()
@@ -932,16 +938,70 @@ class NovaServersTestCase(test.ScenarioTestCase):
 
         scenario._boot_server.assert_called_once_with(image, flavor,
                                                       fakearg="fakearg")
-        net_wrap = mock_wrap.return_value
-        net_wrap.create_floating_ip.assert_called_once_with(
-            tenant_id=server.tenant_id)
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": mock.ANY}
+        )
         scenario._associate_floating_ip.assert_called_once_with(
-            server, net_wrap.create_floating_ip.return_value["ip"])
+            server, floatingip)
+
+        # check ext_network
+        neutronclient.list_networks.return_value = {
+            "networks": [
+                {"id": "id1", "name": "net1", "router:external": True},
+                {"id": "id2", "name": "net2", "router:external": True},
+                {"id": "id3", "name": "net3", "router:external": True},
+            ]
+        }
+        neutronclient.create_floatingip.reset_mock()
+
+        # case 1: new argument is used
+        scenario.run(image, flavor, floating_network="net3")
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id3"}}
+        )
+        # case 2: new argument is transmitted with an old one
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor, floating_network="net3",
+                     create_floating_ip_args={"ext_network": "net2"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id3"}}
+        )
+        # case 3: new argument is transmitted with an semi-old one
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor, floating_network="net3",
+                     create_floating_ip_args={"floating_network": "net1"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id3"}}
+        )
+        # case 4: only old argument is transmitted
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor,
+                     create_floating_ip_args={"ext_network": "net2"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id2"}}
+        )
+        # case 5: only semi-old argument is transmitted
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor,
+                     create_floating_ip_args={"floating_network": "net1"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id1"}}
+        )
+
+    def test_boot_server_associate_and_dissociate_floating_ip(self):
+        clients = mock.MagicMock(credential=mock.MagicMock(api_info={}))
+        neutronclient = clients.neutron.return_value
+        floatingip = "floatingip"
+        neutronclient.create_floatingip.return_value = {
+            "floatingip": floatingip}
 
-    @mock.patch(NOVA_SERVERS_MODULE + ".network_wrapper.wrap")
-    def test_boot_server_associate_and_dissociate_floating_ip(self, mock_wrap):
         scenario = servers.BootServerAssociateAndDissociateFloatingIP(
-            self.context)
+            self.context, clients=clients)
         server = mock.Mock()
         scenario._boot_server = mock.Mock(return_value=server)
         scenario._associate_floating_ip = mock.Mock()
@@ -953,13 +1013,62 @@ class NovaServersTestCase(test.ScenarioTestCase):
 
         scenario._boot_server.assert_called_once_with(image, flavor,
                                                       fakearg="fakearg")
-        net_wrap = mock_wrap.return_value
-        net_wrap.create_floating_ip.assert_called_once_with(
-            tenant_id=server.tenant_id)
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": mock.ANY}
+        )
         scenario._associate_floating_ip.assert_called_once_with(
-            server, net_wrap.create_floating_ip.return_value["ip"])
+            server, floatingip)
         scenario._dissociate_floating_ip.assert_called_once_with(
-            server, net_wrap.create_floating_ip.return_value["ip"])
+            server, floatingip)
+
+        # check ext_network
+        neutronclient.list_networks.return_value = {
+            "networks": [
+                {"id": "id1", "name": "net1", "router:external": True},
+                {"id": "id2", "name": "net2", "router:external": True},
+                {"id": "id3", "name": "net3", "router:external": True},
+            ]
+        }
+        neutronclient.create_floatingip.reset_mock()
+
+        # case 1: new argument is used
+        scenario.run(image, flavor, floating_network="net3")
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id3"}}
+        )
+        # case 2: new argument is transmitted with an old one
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor, floating_network="net3",
+                     create_floating_ip_args={"ext_network": "net2"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id3"}}
+        )
+        # case 3: new argument is transmitted with an semi-old one
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor, floating_network="net3",
+                     create_floating_ip_args={"floating_network": "net1"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id3"}}
+        )
+        # case 4: only old argument is transmitted
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor,
+                     create_floating_ip_args={"ext_network": "net2"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id2"}}
+        )
+        # case 5: only semi-old argument is transmitted
+        neutronclient.create_floatingip.reset_mock()
+        scenario.run(image, flavor,
+                     create_floating_ip_args={"floating_network": "net1"})
+        neutronclient.create_floatingip.assert_called_once_with(
+            {"floatingip": {"description": mock.ANY,
+                            "floating_network_id": "id1"}}
+        )
 
     def test_boot_and_update_server(self):
         scenario = servers.BootAndUpdateServer(self.context)
