@@ -44,6 +44,7 @@ CRED = {
     "project_domain_name": "admin"
 }
 
+NET_PATH = "rally_openstack.common.services.network"
 PATH = "rally_openstack.verification.tempest.context"
 
 
@@ -266,17 +267,17 @@ class TempestContextTestCase(test.TestCase):
         client.create_subnet.side_effect = [{"subnet": {"id": "subid1"}}]
         client.list_networks.return_value = {"networks": []}
 
-        network = self.context._create_network_resources()
-        self.assertEqual("nid1", network["id"])
-        self.assertEqual("nid1", self.context._created_networks[0]["id"])
-        self.assertEqual("rid1",
-                         self.context._created_networks[0]["router_id"])
-        self.assertEqual("subid1",
-                         self.context._created_networks[0]["subnets"][0])
+        net_topo = self.context._create_network_resources()
+
+        self.assertEqual("nid1", net_topo["network"]["id"])
+        self.assertEqual("rid1", net_topo["routers"][0]["id"])
+        self.assertEqual("subid1", net_topo["subnets"][0]["id"])
+
+    @mock.patch("%s.neutron.NeutronService.supports_extension" % PATH)
+    def test__create_network_resources_public_network_override(
+            self, mock_supports_extension):
+        mock_supports_extension.return_value = True
 
-    @mock.patch("rally_openstack.common.wrappers.network.NeutronWrapper.ext_gw_mode_enabled",  # noqa E501
-                new_callable=mock.PropertyMock, return_value=True)
-    def test__create_network_resources_public_network_override(self, mock_ext_gw_mode_enabled):  # noqa E501
         client = self.context.clients.neutron()
         conf = self.context.conf
 
@@ -348,15 +349,16 @@ class TempestContextTestCase(test.TestCase):
         self.assertEqual("", self.context.conf.get("orchestration",
                                                    "instance_type"))
 
-    @mock.patch("rally_openstack.common.wrappers."
-                "network.NeutronWrapper.delete_network")
-    def test__cleanup_network_resources(
-            self, mock_neutron_wrapper_delete_network):
-        self.context._created_networks = [{"name": "net-12345"}]
+    @mock.patch("%s.neutron.NeutronService.delete_network_topology" % PATH)
+    def test__cleanup_network_resources(self, mock_delete_network_topology):
+        self.context._created_networks = [{"network": {"name": "net-12345"}}]
         self.context.conf.set("compute", "fixed_network_name", "net-12345")
 
         self.context._cleanup_network_resources()
-        self.assertEqual(1, mock_neutron_wrapper_delete_network.call_count)
+
+        mock_delete_network_topology.assert_called_once_with(
+            self.context._created_networks[0]
+        )
         self.assertEqual("", self.context.conf.get("compute",
                                                    "fixed_network_name"))
 
@@ -367,7 +369,7 @@ class TempestContextTestCase(test.TestCase):
     def test_setup(self, mock_create_dir,
                    mock__create_tempest_roles, mock__configure_option,
                    mock_open):
-        verifier = mock.Mock(env=self.env)
+        verifier = mock.Mock(env=self.env, version="27.1.0")
         verifier.manager.home_dir = "/p/a/t/h"
 
         # case #1: no neutron and heat
@@ -385,8 +387,7 @@ class TempestContextTestCase(test.TestCase):
         self.assertEqual(
             [mock.call("DEFAULT", "log_file", "/p/a/t/h/tempest.log"),
              mock.call("oslo_concurrency", "lock_path", "/p/a/t/h/lock_files"),
-             mock.call("scenario", "img_dir", "/p/a/t/h"),
-             mock.call("scenario", "img_file", ctx.image_name,
+             mock.call("scenario", "img_file", "/p/a/t/h/" + ctx.image_name,
                        helper_method=ctx._download_image),
              mock.call("compute", "image_ref",
                        helper_method=ctx._discover_or_create_image),
@@ -425,8 +426,7 @@ class TempestContextTestCase(test.TestCase):
         self.assertEqual([
             mock.call("DEFAULT", "log_file", "/p/a/t/h/tempest.log"),
             mock.call("oslo_concurrency", "lock_path", "/p/a/t/h/lock_files"),
-            mock.call("scenario", "img_dir", "/p/a/t/h"),
-            mock.call("scenario", "img_file", ctx.image_name,
+            mock.call("scenario", "img_file", "/p/a/t/h/" + ctx.image_name,
                       helper_method=ctx._download_image),
             mock.call("compute", "image_ref",
                       helper_method=ctx._discover_or_create_image),
@@ -447,3 +447,16 @@ class TempestContextTestCase(test.TestCase):
                       flv_ram=config.CONF.openstack.heat_instance_type_ram,
                       flv_disk=config.CONF.openstack.heat_instance_type_disk)
         ], mock__configure_option.call_args_list)
+
+        # case 3: tempest is old.
+        verifier.version = "17.0.0"
+        ctx = context.TempestContext({"verifier": verifier})
+        ctx.conf = mock.Mock()
+        ctx.setup()
+        mock__configure_option.assert_has_calls(
+            [
+                mock.call("scenario", "img_dir", "/p/a/t/h"),
+                mock.call("scenario", "img_file", ctx.image_name,
+                          helper_method=ctx._download_image)
+            ]
+        )
